@@ -25,8 +25,6 @@ using namespace PimCommon::ConfigureImmutableWidgetUtils;
 #include "MessageViewer/PrintingSettings"
 #include "messageviewer/messageviewersettings.h"
 
-#include "MessageViewer/PrintingSettings"
-
 #include <KLocalizedString>
 #include <QHBoxLayout>
 
@@ -70,7 +68,7 @@ MiscPageFolderTab::MiscPageFolderTab(QWidget *parent)
     layout->addWidget(mOnStartupOpenFolder);
 
     mMMTab.mExcludeImportantFromExpiry->setWhatsThis(
-        i18n(KMailSettings::self()->excludeImportantMailFromExpiryItem()->whatsThis().toUtf8()));
+        i18n(KMailSettings::self()->excludeImportantMailFromExpiryItem()->whatsThis().toUtf8().constData()));
 
     connect(mMMTab.mExcludeImportantFromExpiry, &QCheckBox::stateChanged, this, &MiscPageFolderTab::slotEmitChanged);
     connect(mMMTab.mLoopOnGotoUnread, QOverload<int>::of(&KComboBox::activated), this, &MiscPageFolderTab::slotEmitChanged);
@@ -83,6 +81,7 @@ MiscPageFolderTab::MiscPageFolderTab(QWidget *parent)
     connect(mMMTab.mEmptyTrashCheck, &QCheckBox::stateChanged, this, &MiscPageFolderTab::slotEmitChanged);
     connect(mMMTab.mStartUpFolderCheck, &QCheckBox::toggled, this, &MiscPageFolderTab::slotEmitChanged);
     connect(mMMTab.mStartUpFolderCheck, &QCheckBox::toggled, mOnStartupOpenFolder, &MailCommon::FolderRequester::setEnabled);
+    connect(mMMTab.mDeleteMessagesWithoutConfirmation, &QCheckBox::toggled, this, &MiscPageFolderTab::slotEmitChanged);
 }
 
 void MiscPage::FolderTab::doLoadFromGlobalSettings()
@@ -96,6 +95,9 @@ void MiscPage::FolderTab::doLoadFromGlobalSettings()
     loadWidget(mMMTab.mShowPopupAfterDnD, KMailSettings::self()->showPopupAfterDnDItem());
     loadWidget(mMMTab.mStartUpFolderCheck, KMailSettings::self()->startSpecificFolderAtStartupItem());
     mOnStartupOpenFolder->setEnabled(KMailSettings::self()->startSpecificFolderAtStartup());
+
+    loadWidget(mMMTab.mDeleteMessagesWithoutConfirmation, KMailSettings::self()->deleteMessageWithoutConfirmationItem());
+
     doLoadOther();
 }
 
@@ -118,6 +120,7 @@ void MiscPage::FolderTab::save()
     saveCheckBox(mMMTab.mExcludeImportantFromExpiry, KMailSettings::self()->excludeImportantMailFromExpiryItem());
     saveCheckBox(mMMTab.mShowPopupAfterDnD, KMailSettings::self()->showPopupAfterDnDItem());
     saveCheckBox(mMMTab.mStartUpFolderCheck, KMailSettings::self()->startSpecificFolderAtStartupItem());
+    saveCheckBox(mMMTab.mDeleteMessagesWithoutConfirmation, KMailSettings::self()->deleteMessageWithoutConfirmationItem());
 }
 
 MiscPageInviteTab::MiscPageInviteTab(QWidget *parent)
