@@ -44,6 +44,7 @@
 #include <MessageComposer/PluginEditor>
 #include <MessageViewer/HeaderStylePlugin>
 #include <AkonadiCore/AgentManager>
+#include <AkonadiCore/AgentInstance>
 
 namespace {
 QString pluginEditorGroupName()
@@ -237,11 +238,12 @@ void ConfigurePluginsListWidget::initialize()
 void ConfigurePluginsListWidget::initializeAgentPlugins()
 {
     mPluginUtilDataList.clear();
-    mPluginUtilDataList.reserve(4);
+    mPluginUtilDataList.reserve(5);
     mPluginUtilDataList << createAgentPluginData(QStringLiteral("akonadi_sendlater_agent"), QStringLiteral("/SendLaterAgent"));
     mPluginUtilDataList << createAgentPluginData(QStringLiteral("akonadi_archivemail_agent"), QStringLiteral("/ArchiveMailAgent"));
     mPluginUtilDataList << createAgentPluginData(QStringLiteral("akonadi_newmailnotifier_agent"), QStringLiteral("/NewMailNotifierAgent"));
     mPluginUtilDataList << createAgentPluginData(QStringLiteral("akonadi_followupreminder_agent"), QStringLiteral("/FollowUpReminder"));
+    mPluginUtilDataList << createAgentPluginData(QStringLiteral("akonadi_unifiedmailbox_agent"), QStringLiteral("/UnifiedMailboxAgent"));
 
     PimCommon::ConfigurePluginsListWidget::fillTopItems(mPluginUtilDataList,
                                                         i18n("Akonadi Agents"),
@@ -335,12 +337,9 @@ void ConfigurePluginsListWidget::slotConfigureClicked(const QString &configureGr
         } else if (configureGroupName == agentAkonadiGroupName()) {
             for (const PimCommon::PluginUtilData &data : qAsConst(mPluginUtilDataList)) {
                 if (data.mIdentifier == identifier) {
-                    const QString service = Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Agent, data.mExtraInfo.at(0));
-                    QDBusInterface interface(service, data.mExtraInfo.at(1));
-                    if (interface.isValid()) {
-                        interface.call(QStringLiteral("showConfigureDialog"), static_cast<qlonglong>(winId()));
-                    } else {
-                        qCDebug(KMAIL_LOG) << " interface does not exist when trying to configure the plugin";
+                    auto instance = Akonadi::AgentManager::self()->instance(identifier);
+                    if (instance.isValid()) {
+                        instance.configure(this);
                     }
                     break;
                 }
