@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -27,7 +27,7 @@ class StatusBarLabelToggledState : public QLabel
     Q_OBJECT
 public:
     explicit StatusBarLabelToggledState(QWidget *parent = nullptr);
-    ~StatusBarLabelToggledState();
+    ~StatusBarLabelToggledState() override;
 
     void setToggleMode(bool state);
 
